@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,6 +38,7 @@ import com.openexchange.conversion.simple.SimpleConverter;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.groupware.userconfiguration.osgi.PermissionRelevantServiceAddedTracker;
 import com.openexchange.java.Streams;
+import com.openexchange.java.Strings;
 import com.openexchange.osgi.RankingAwareNearRegistryServiceTracker;
 import com.openexchange.passwordchange.PasswordChangeService;
 import com.openexchange.serverconfig.ComputedServerConfigValueService;
@@ -125,12 +126,12 @@ public class ManifestJSONActivator extends AJAXModuleActivator implements Forced
                 if (null == property) {
                     return new JSONArray(0);
                 }
-                paths = property.split(":");
+                paths = Strings.splitByColon(property);
                 for (int i = 0; i < paths.length; i++) {
                     paths[i] += "/manifests";
                 }
             } else {
-                paths = property.split(":");
+                paths = Strings.splitByColon(property);
             }
         }
 
