@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -102,7 +102,7 @@ public class HistoryUtil {
         }
 
         destFolder.setWritable(true);
-        LOG.debug("Starting to copy installed files to current (targte: {}).", destFolder.getAbsolutePath());
+        LOG.debug("Starting to copy installed files to current (target: {}).", destFolder.getAbsolutePath());
         @SuppressWarnings("null") CopyFileVisitor visitor = new CopyFileVisitor(installed.toPath(), destFolder.toPath());
         Files.walkFileTree(installed.toPath(), visitor);
         adjustPathOwner(destFolder.toPath());
@@ -124,7 +124,7 @@ public class HistoryUtil {
             FileUtils.deleteDirectory(to);
             LOG.info("Previous files deleted successfully (target: {}).", to.getAbsolutePath());
         }
-        LOG.debug("Starting to move current files to previous (targte: {}).", to.getAbsolutePath());
+        LOG.debug("Starting to move current files to previous (target: {}).", to.getAbsolutePath());
 
         to.mkdirs();
 
