@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -35,6 +35,7 @@ import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.ForcedReloadable;
 import com.openexchange.config.Reloadable;
 import com.openexchange.dispatcher.DispatcherPrefixService;
+import com.openexchange.java.Strings;
 import com.openexchange.login.LoginRampUpService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.osgi.RankingAwareNearRegistryServiceTracker;
@@ -125,7 +126,7 @@ public class AppsuiteActivator extends HousekeepingActivator implements ForcedRe
             throw new BundleException("Missing property: com.openexchange.apps.path", BundleException.ACTIVATOR_ERROR);
         }
 
-        String[] paths = property.split(":");
+        String[] paths = Strings.splitByColon(property);
         List<File> apps = new ArrayList<File>(paths.length);
         Optional<String> winPrefix = Optional.empty();
         for (int i = 0; i < paths.length; i++) {
